Re-exports
pub use error::Error;pub use value::Number;pub use value::Value;pub use writer::Options;pub use writer::Writer;
Modules
- error
- Provides the crate’s Error and Result types as well as helper functions.
- value
- This module provides the common
Valueenum for atomic values (bool, integer, float, character, string, symbol, and keyword) and lists of values. - writer
- This module provides the ability to write
Values in different language styles with an option to pretty print nested values.